==> 0.0.19.tar.gz: ios/Classes/entity/V2GroupInfoEntity.swift <==
import Foundation
import ImSDK_Smart

/// 自定义群信息实体
class V2GroupInfoEntity: V2TIMGroupInfo {

    required public override init() {
    }

//    convenience init(dict: Dictionary<String, Any>) {
//        self.init(dict: dict)
//    }

    init(dict: [String: Any]) {
        super.init();
        self.groupID = (dict["groupID"] as? String);
        self.groupType = (dict["groupType"] as? String);
        self.groupName = (dict["groupName"] as? String);
        self.notification = (dict["notification"] as? String);
        self.introduction = (dict["introduction"] as? String);
        self.faceURL = (dict["faceUrl"] as? String);
        if dict["allMuted"] != nil {
            self.allMuted = (dict["allMuted"] as! Bool);
        }
        if dict["groupAddOpt"] != nil {
            self.groupAddOpt = V2TIMGroupAddOpt.init(rawValue: (dict["groupAddOpt"] as! Int))!;
        }
    }

    /// 根据对象获得字典对象
    public static func getDict(info: V2TIMGroupInfo) -> [String: Any] {
        var result: [String: Any] = [:];
        result["groupID"] = info.groupID;
        result["groupType"] = info.groupType;
        result["groupName"] = info.groupName;
        result["notification"] = info.notification;
        result["introduction"] = info.introduction;
        result["faceUrl"] = info.faceURL;
        result["allMuted"] = info.allMuted;
        result["owner"] = info.owner;
        result["createTime"] = info.createTime;
        result["groupAddOpt"] = info.groupAddOpt.rawValue;
        result["lastInfoTime"] = info.lastInfoTime;
        result["lastMessageTime"] = info.lastMessageTime;
        result["memberCount"] = info.memberCount;
        result["onlineCount"] = info.onlineCount;
        result["role"] = info.role.rawValue;
        result["recvOpt"] = info.recvOpt.rawValue;
        result["joinTime"] = info.joinTime;
        return result;
    }
}

==> 1.0.23.tar.gz: ios/Classes/entity/V2GroupInfoEntity.swift <==
import Foundation
import ImSDK_Smart

/// 自定义群信息实体
class V2GroupInfoEntity: V2TIMGroupInfo {

    required public override init() {
    }

//    convenience init(dict: Dictionary<String, Any>) {
//        self.init(dict: dict)
//    }

    init(dict: [String: Any]) {
        super.init();
        self.groupID = (dict["groupID"] as? String);
        self.groupType = (dict["groupType"] as? String);
        self.groupName = (dict["groupName"] as? String);
        self.notification = (dict["notification"] as? String);
        self.introduction = (dict["introduction"] as? String);
        self.faceURL = (dict["faceUrl"] as? String);
        if dict["allMuted"] != nil {
            self.allMuted = (dict["allMuted"] as! Bool);
        }
        if dict["addOpt"] != nil {
            self.groupAddOpt = V2TIMGroupAddOpt.init(rawValue: (dict["addOpt"] as! Int))!;
        }
    }

    /// 根据对象获得字典对象
    public static func getDict(info: V2TIMGroupInfo) -> [String: Any] {
        var result: [String: Any] = [:];
        result["groupID"] = info.groupID;
        result["groupType"] = info.groupType;
        result["groupName"] = info.groupName;
        result["notification"] = info.notification;
        result["introduction"] = info.introduction;
        result["faceUrl"] = info.faceURL;
        result["allMuted"] = info.allMuted;
        result["owner"] = info.owner;
        result["createTime"] = info.createTime;
        result["groupAddOpt"] = info.groupAddOpt.rawValue;
        result["lastInfoTime"] = info.lastInfoTime;
        result["lastMessageTime"] = info.lastMessageTime;
        result["memberCount"] = info.memberCount;
        result["onlineCount"] = info.onlineCount;
        result["role"] = info.role.rawValue;
        result["recvOpt"] = info.recvOpt.rawValue;
        result["joinTime"] = info.joinTime;
        return result;
    }
}
